@@ -34,7 +34,6 @@
 #include "seahorse-tool.h"
 #include "seahorse-util.h"
 #include "seahorse-widget.h"
-#include "seahorse-gconf.h"
 #include "seahorse-vfs-data.h"
 
 #define ONE_GIGABYTE 1024 * 1024 * 1024
@@ -406,7 +405,7 @@ prepare_dialog (FilesCtx *ctx, guint nfolders, guint nfiles, GFileInfo *info, gc
     /* The local stuff */
     } else {
 
-        sep = seahorse_gconf_get_boolean (MULTI_SEPERATE_KEY);
+        sep = g_settings_get_boolean (seahorse_tool_settings, "separate-files");
 
         /* Setup the package */
         w = GTK_WIDGET (seahorse_widget_get_widget (swidget, "package-name"));
@@ -433,11 +432,7 @@ prepare_dialog (FilesCtx *ctx, guint nfolders, guint nfiles, GFileInfo *info, gc
         save_type_list = save_type;
 
         for (i = 0; save_type_list[i] != FR_FILE_TYPE_NULL; i++) {
-#if GTK_CHECK_VERSION(2,23,0)
 		gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (combo),
-#else
-		gtk_combo_box_append_text (GTK_COMBO_BOX (combo),
-#endif
 		                                file_type_desc[save_type_list[i]].ext);
 		    if (strcmp(ext, file_type_desc[save_type_list[i]].ext) == 0)
 		        gtk_combo_box_set_active (GTK_COMBO_BOX (combo), i);
@@ -469,7 +464,7 @@ get_results (SeahorseWidget *swidget)
 
     w = GTK_WIDGET (seahorse_widget_get_widget (swidget, "do-separate"));
     sep = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (w));
-    seahorse_gconf_set_boolean (MULTI_SEPERATE_KEY, sep);
+    g_settings_set_boolean (seahorse_tool_settings, "separate-files", sep);
 
     /* no packaging */
     if(!sep) {
@@ -478,11 +473,7 @@ get_results (SeahorseWidget *swidget)
         name = gtk_entry_get_text (GTK_ENTRY (w));
 
         w = GTK_WIDGET (seahorse_widget_get_widget (swidget, "package-extension"));
-#if GTK_CHECK_VERSION(2,23,0)
         ext = gtk_combo_box_text_get_active_text (GTK_COMBO_BOX_TEXT (w));
-#else
-        ext = gtk_combo_box_get_active_text (GTK_COMBO_BOX (w));
-#endif
 
         /* No paths */
         t = strrchr(name, '/');
@@ -496,7 +487,7 @@ get_results (SeahorseWidget *swidget)
         full_name = g_strdup_printf("%s%s", name, ext);
 
         /* Save the extension */
-        seahorse_gconf_set_string (MULTI_EXTENSION_KEY, ext);
+        g_settings_set_string (seahorse_tool_settings, "package-extension", ext);
 
         return full_name;
     }
@@ -537,7 +528,7 @@ step_process_multiple (FilesCtx *ctx,
         return TRUE;
 
     /* The package extension */
-    if ((ext = seahorse_gconf_get_string (MULTI_EXTENSION_KEY)) == NULL)
+    if ((ext = g_settings_get_string (seahorse_tool_settings, "package-extension")) == NULL)
         ext = g_strdup (".zip"); /* Yes this happens when the schema isn't installed */
 
     /* Figure out a good URI for our package */
